package com.onbon.sdklibrary

import android.content.Context

interface SdkInterface {
    /**
     * 设置系统熄屏与开屏
     * @param isOn true为开屏，false为熄屏
     * @return 设置是否成功
     */
    fun switchPowerState(isOn: Boolean, context: Context): Boolean

    /**
     * 设置屏幕旋转角度
     * @param rotation 0为0度，1为90度，2为180度，3为270度
     */
    fun setScreenRotation(context: Context, rotation: Int): Boolean

    /**
     * 获取当前旋转参数
     * @return 当前的旋转值：0为0度，1为90度，2为180度，3为270度
     */
    fun getScreenRotation(context: Context): Int

    /**
     * 设置系统定时开机
     * @param paramInt 间隔时长(S)，指设定的开机时间与当前时间的间隔时长，单位为秒
     * 比如当前为2023年10月10号，11点20分30秒，设定的开机时间为2023年10月11日 8点20分0秒；
     * 相当于间隔20小时59分30秒后开机，此时参数应该填：75570
     */
    fun setPowerOnAlarm(paramInt: Int): Boolean

    /**
     * 系统关机
     * @return 执行结果
     */
    fun close(): Boolean

    /**
     * 系统重启
     * @return 执行结果
     */
    fun reboot(): Boolean

    /**
     * 获取系统截图
     * @param suffix 截图文件的后缀如：png
     * @param dir 截图文件的保存路径如：Sdcard/ScreenShot/
     * @return 返回带当前时间戳的截图文件的精准路径
     */
    fun screenShot(suffix: String, dir: String): String

    /**
     * 静默安装
     * @param context：上下文对象
     * @param apkFilePath：apk路径
     * @param packageName：apk 包名
     * @param autoStart：true代表安装后app自动启动，false代表安装后app不启动
     */
    fun silentInstall(context: Context, apkFilePath: String, packageName: String, autoStart: String)

    /**
     * 设置系统时间
     * @param dataTime:时间字符串，例：2023-10-30 11:10:11
     */
    fun setSystemClock(dataTime: String)
}